# Sequence Mixer


::: linax.sequence_mixers.base.SequenceMixerConfig
    options:
        members:
            - build

---

::: linax.sequence_mixers.base.SequenceMixer
    options:
        members:
            - __init__
            - __call__
